@@ -61,9 +61,9 @@ class Config():
     # 图片压缩相关配置
     COMPRESS_INFO_STATUS = "status"
     COMPRESS_INFO_LIMIT = "limit"
-    # COMPRESS_ENGINE = "engine"
     COMPRESS_ENGINE_GIL = "GIL"
     COMPRESS_ENGINE_TIYPNG = "tinyPNG"
+    COMPRESS_ENGINE_NONE = "none"
     smmsTokenFile = ""
     configFile = ""
     mainConfig = {}
@@ -236,11 +236,4 @@ class Config():
     def getCompressInfo(self):
         """获取图片压缩配置信息"""
         info = self.getConfigParam(Config.PARAM_COMPRESS)
-        # if info == '':
-        #     info = {Config.COMPRESS_INFO_LIMIT: 500,
-        #             Config.COMPRESS_INFO_STATUS: "off",
-        #             Config.COMPRESS_ENGINE: Config.COMPRESS_ENGINE_GIL}
-        # if Config.COMPRESS_ENGINE not in info:
-        #     info[Config.COMPRESS_ENGINE] = Config.COMPRESS_ENGINE_GIL
-        #     self.setConfigParam(Config.PARAM_COMPRESS, info)
         return info
